## Ver. 1.5.0 - 2016-Oct-11

This version brings several improvements and enhancements in the internal API.
It is broadly compatible with the 1.4 series with the exception of the media component in the
WSGI strings. Importantly, multi-processing is handled directly by asyncio
rather than the [multiprocessing](https://docs.python.org/3/library/multiprocessing.html) module.
It is still possible to use the ``multiprocessing`` module via ``--concurrency multi``
command line/config flag.
Support for [uvloop](https://github.com/MagicStack/uvloop) has been added.
To use the this third party event loop, pass the ``--io uv`` flag in the command line.

* Several internal changes for better asyncio API support, dropped all private methods
* Process based actors are created using asyncio subprocess API
* Actor based on the multiprocessing module are created via the ``multi`` concurrency flag
* Added the ``bench`` setup.py command [#247](https://github.com/quantmind/pulsar/issues/247)
* Added ``pulsar.create_future`` function, a shortcut for ``loop.create_future``
* Added support for [uvloop](https://github.com/MagicStack/uvloop)
* Removed tweet example and created a new repository [pulsar-twitter](https://github.com/quantmind/pulsar-twitter)
* Removed ``require`` script from wsgi media and refactoring [#239](https://github.com/quantmind/pulsar/issues/239)
* Test.wait only support ``assertRaises`` [#235](https://github.com/quantmind/pulsar/issues/235)
* Removed ``yield from`` from all tests
* No more docs in http://pythonhosted.org/pulsar/

